primecountpy: Cython interface for C++ primecount library
=========================================================

Description
-----------

Cython interface for C++ primecount library

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/primecountpy/

